summaryrefslogtreecommitdiff
path: root/tests/test-homescreen.c
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test-homescreen.c')
-rw-r--r--tests/test-homescreen.c22
1 files changed, 10 insertions, 12 deletions
diff --git a/tests/test-homescreen.c b/tests/test-homescreen.c
index 9b7fc68..8754ac4 100644
--- a/tests/test-homescreen.c
+++ b/tests/test-homescreen.c
@@ -1016,28 +1016,26 @@ raise_surface(struct display *display, char *buf, const int raise)
}
static void
-transition_surface(struct display *display, char *buf)
+animation_surface(struct display *display, char *buf)
{
char *args[10];
int narg;
int surfaceid;
- int transition;
narg = pars_command(buf, args, 10);
if (narg >= 2) {
surfaceid = search_surface(display, args[0]);
- transition = strtol(args[1], (char **)0, 0);
- if ((surfaceid >= 0) && (transition >=0)) {
- print_log("HOMESCREEN: transition(%s,%08x,%d)", args[0], surfaceid, transition);
- ico_window_mgr_set_transition(display->ico_window_mgr, surfaceid, transition);
+ if (surfaceid >= 0) {
+ print_log("HOMESCREEN: animation(%s,%08x,%s)", args[0], surfaceid, args[1]);
+ ico_window_mgr_set_animation(display->ico_window_mgr, surfaceid, args[1]);
}
else {
- print_log("HOMESCREEN: Unknown surface(%s) at transition command", args[0]);
+ print_log("HOMESCREEN: Unknown surface(%s) at animation command", args[0]);
}
}
else {
- print_log("HOMESCREEN: transition command"
- "[transition appid transition] has no argument");
+ print_log("HOMESCREEN: animation command"
+ "[animation appid animation] has no argument");
}
}
@@ -1406,9 +1404,9 @@ int main(int argc, char *argv[])
/* Raise/Lower surface window */
raise_surface(display, &buf[5], 0);
}
- else if (strncasecmp(buf, "transition", 10) == 0) {
- /* Set transition surface window*/
- transition_surface(display, &buf[10]);
+ else if (strncasecmp(buf, "animation", 9) == 0) {
+ /* Set animation surface window*/
+ animation_surface(display, &buf[10]);
}
else if (strncasecmp(buf, "input_add", 9) == 0) {
/* Set input switch to application */